@@ -8,7 +8,7 @@ use Encode;
 use File::Spec;
 use YAML::Tiny ();
 
-use version 0.77; our $VERSION = version->declare("v0.4.2");
+use version 0.77; our $VERSION = version->declare("v0.9.0");
 
 __PACKAGE__->setting(
     handle_static => 1,
@@ -21,8 +21,7 @@ sub load_config {
     my $self = shift;
     my $file = File::Spec->catfile($self->base_dir, 'riji.yml');
     unless (-e $file) {
-        warn 'config file not found';
-        return +{};
+        die sprintf "config file: [%s] not found.\n", $file;
     }
     YAML::Tiny::LoadFile($file);
 }
@@ -120,8 +119,6 @@ Riji is a simple and git based blog tool.
 
 'Riji' means diary in Chinese.
 
-B<THE SOFTWARE IS ALPHA QUALITY. API MAY CHANGE WITHOUT NOTICE.>
-
 =head1 LICENSE
 
 Copyright (C) Masayuki Matsuki.
