@@ -5,7 +5,7 @@ use warnings;
 
 sub run {
     my ($class, @argv) = @_;
-    say 'help!';
+    say 'First, command `% riji setup` in empty directory.';
 }
 
 1;
